{
  config,
  # inputs,
  lib,
  pkgs,
  ...
}: let
  inherit (lib) mkDefault mkEnableOption mkIf;
  cfg = config.module.config;
in {
  imports = [
    ./boot
    ./hardware
    ./misc
    ./networking
    ./nix
    ./security
    ./programs.nix
    ./services.nix
    ./users.nix
    ./sops.nix
  ];
  options = {
    module.config = {
      laptop.homeRowMods = mkEnableOption "set to have mods on asdfjkl;";
      powerSave = mkEnableOption "set to use various power saving daemons";
      secureBoot = mkEnableOption "set if secure boot is configured";
      tpmDiskUnlock = mkEnableOption "set if luks enrolled in tpm2";
      useIwd = mkEnableOption "set to use iwd instead of wpa-supplicant";
      vaapi = lib.mkOption {
        type = lib.types.nullOr (lib.types.enum ["intel-media-driver" "nvidia"]);
        default = null;
      };
    };
  };
  config = lib.mkMerge [
    {
      boot.initrd.systemd.tpm2.enable = mkDefault cfg.tpmDiskUnlock;
      boot.loader.systemd-boot.enable = mkDefault (!cfg.secureBoot);
    }
    (mkIf (cfg.laptop.homeRowMods) {
      services.keyd = {
        enable = true;
        keyboards = {
          internal = {
            ids = ["0001:0001" "048d:c101"];
            settings.main = let
              # finger = mod;
              pinky = "alt";
              ring = "meta";
              middle = "control";
              index = "shift";
              # timeouts
              idle = "200";
              hold = "150";
              # function takes finger and letter
              homeRowMod = f: l: "lettermod(${f}, ${l}, ${idle}, ${hold})";
            in {
              "a" = homeRowMod pinky "a";
              "s" = homeRowMod ring "s";
              "d" = homeRowMod middle "d";
              "f" = homeRowMod index "f";
              "j" = homeRowMod index "j";
              "k" = homeRowMod middle "k";
              "l" = homeRowMod ring "l";
              ";" = homeRowMod pinky ";";
            };
          };
        };
      };
    })
    (mkIf (cfg.powerSave) {
      powerManagement.enable = true;
      powerManagement.powertop.enable = true;
      services.power-profiles-daemon.enable = true;
      services.thermald.enable = true;
      services.upower.enable = true;
    })
    (mkIf cfg.useIwd {
      networking = {
        networkmanager.wifi.backend = "iwd";
        wireless.iwd.enable = true;
      };
    })
    (mkIf (cfg.vaapi == "intel-media-driver") {
      hardware.graphics.extraPackages = with pkgs; [
        intel-compute-runtime
        intel-media-driver
        vpl-gpu-rt
      ];
    })
    (mkIf (cfg.vaapi == "nvidia") {
      hardware.graphics.extraPackages = with pkgs; [
        nvidia-vaapi-driver
      ];
    })
  ];
}
